@@ -185,8 +185,10 @@ class ROCv3():
 
     def _translate(self, valid_config: dict,
                    translation_dictionary=None,
-                   registers=[],
+                   translation_output_registers=[],
                    transaction_log_written=False) -> list:
+        # do this to avoid weird referencing and static variable behaviour
+        translation_output_registers = translation_output_registers.copy()
         if not transaction_log_written:
             self.transaction_logger.debug(
                 "Translating configuration dictionary")
@@ -195,10 +197,11 @@ class ROCv3():
             translation_dictionary = self.translation_dict
         for key, val in valid_config.items():
             if isinstance(val, dict):
-                self._translate(val,
-                                translation_dictionary[key],
-                                registers,
-                                transaction_log_written=True)
+                translation_output_registers += self._translate(
+                        val,
+                        translation_dictionary[key],
+                        translation_output_registers,
+                        transaction_log_written=True)
             else:
                 param_registers = translation_dictionary[key].keys()
                 masks = translation_dictionary[key].values()
@@ -206,9 +209,9 @@ class ROCv3():
                     aligned_val = \
                         ((val & m['param_mask']) >> m['param_minbit'])\
                         << m['reg_minbit']
-                    registers.append(
+                    translation_output_registers.append(
                             (r[0], r[1], aligned_val, m['reg_mask']))
-        return registers
+        return translation_output_registers
 
     def _translate_read(self, valid_config, translation_dictionary=None,
                         curr_key=[], param_reg_pairs=[],
@@ -273,7 +276,8 @@ class ROCv3():
             raise KeyError(str(err.args[0]) + f" in ROC {self.name}")
         except ValueError as err:
             raise ValueError(str(err.args[0]) + f" in ROC {self.name}")
-        register_updates = self._translate(configuration)
+        register_updates = self._translate(configuration,
+                                           translation_output_registers=[])
         register_writes = self._cache(register_updates)
         self.transaction_logger.info("Updating configuration in "
                                      f'{len(register_writes)} registers')
